// $Id:
// FORESTER -- software libraries and applications
// for evolutionary biology research and applications.
//
// Copyright (C) 2008-2009 Christian M. Zmasek
// Copyright (C) 2008-2009 Burnham Institute for Medical Research
// Copyright (C) 2000-2001 Washington University School of Medicine
// and Howard Hughes Medical Institute
// All rights reserved
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
//
// Contact: phylosoft @ gmail . com
// WWW: www.phylosoft.org/forester

package org.forester.phylogeny.data;

import java.io.IOException;
import java.io.Writer;
import java.math.BigDecimal;

import org.forester.io.parsers.phyloxml.PhyloXmlMapping;
import org.forester.util.ForesterUtil;
import org.forester.io.parsers.nhx.NHXFormatException;
import org.forester.io.parsers.nhx.NHXtags;
import org.forester.io.writers.PhylogenyWriter;

public class Pagan implements PhylogenyData {

    private String     _desc;

    public Pagan() {
        _desc = "";
    }

    public Pagan( final String desc ) {
        if ( desc == null ) {
            throw new IllegalArgumentException( "illegaly empty of null fields in constructor" );
        }
        _desc = desc;
    }

    @Override
    public StringBuffer asSimpleText() {
	return new StringBuffer( getDesc() );
    }

    @Override
    public StringBuffer asText() {
        return asSimpleText();
    }

    @Override
    public PhylogenyData copy() {
        return new Pagan( getDesc() );
    }

    public String getDesc() {
        return _desc;
    }

    @Override
    public boolean isEqual( final PhylogenyData data ) {
        throw new UnsupportedOperationException();
    }

    public void setDesc( final String desc ) {
        _desc = desc;
    }

   @Override
    public StringBuffer toNHX() {
        final StringBuffer sb = new StringBuffer();
        if ( getDesc() != null ) {
            sb.append( ':' + NHXtags.PAGAN_TID );
            sb.append( ForesterUtil.replaceIllegalNhxCharacters( getDesc() ) );
        }
        return sb;
    }

    @Override
    public void toPhyloXML( final Writer writer, final int level, final String indentation ) throws IOException {
        throw new UnsupportedOperationException();
    }

    @Override
    public String toString() {
        return asSimpleText().toString();
    }
}